"""
Function to retrieve default MNP draagkracht for species/bt combination
"""

import pandas as pd
import numpy as np

# Get default mnp draagkracht values
mnp_dk_src = r'w:\PROJECTS\qmar\MNP-SNL-ParameterSet\Parameters_v06_2019_12_09\03_MNP_versie6_par_density_factors_BT2019_v2.csv'
mnp_dk = pd.read_csv(mnp_dk_src, sep=',',usecols=['Species_code', 'Land_type_code', 'Land_type_quality'])


def get_mnp_dk(species_code, bt_code, tab=mnp_dk):
    """

    :param species_code: MNP species code starting with S02, S06, S09
    :param bt_code: BT code NXX.YY.ZZ
    :param tab: source table
    :return: float draagrkacht
    """

    dk = mnp_dk.loc[(mnp_dk.Species_code == species_code) & (mnp_dk.Land_type_code == bt_code), 'Land_type_quality']
    if not dk.empty:
        return float(dk)
    else:
        return np.nan


